Module: Deeprails::Models::DefendCreateWorkflowParams::ImprovementAction
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/deeprails/models/defend_create_workflow_params.rb
Overview
The action used to improve outputs that fail one or more guardrail metrics for
the workflow events. May be regen, fixit, or do_nothing. ReGen runs the
user's input prompt with minor induced variance. FixIt attempts to directly
address the shortcomings of the output using the guardrail failure rationale. Do
Nothing does not attempt any improvement.
Constant Summary collapse
- REGEN =
:regen- FIXIT =
:fixit- DO_NOTHING =
:do_nothing
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info