Module: Deeprails::Models::DefendResponse::Event::Evaluation::ImprovementToolStatus

Extended by:
Internal::Type::Enum
Defined in:
lib/deeprails/models/defend_response.rb

Overview

Status of the improvement tool used to improve the event. improvement_required indicates that the evaluation is complete and the improvement action is needed but is not taking place. improved and improvement_failed indicate when the improvement action concludes, successfully and unsuccessfully, respectively. no_improvement_required means that the first evaluation passed all its metrics!

Constant Summary collapse

IMPROVED =
:improved
IMPROVEMENT_FAILED =
:improvement_failed
NO_IMPROVEMENT_REQUIRED =
:no_improvement_required
IMPROVEMENT_REQUIRED =
:improvement_required

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info