Class: Deeprails::Models::DefendUpdateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/deeprails/models/defend_update_response.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(modified_at:, status:, workflow_id:, name: nil) ⇒ Object

Some parameter documentations has been truncated, see Deeprails::Models::DefendUpdateResponse for more details.

Parameters:

  • modified_at (Time) —

    The time the workflow was last modified in UTC.

  • status (Symbol, Deeprails::Models::DefendUpdateResponse::Status) —

    Status of the selected workflow. May be inactive or active. Inactive workf

  • workflow_id (String) —

    A unique workflow ID.

  • name (String) (defaults to: nil) —

    The name of the workflow.



# File 'lib/deeprails/models/defend_update_response.rb', line 32


Instance Attribute Details

#modified_at ⇒ Time

The time the workflow was last modified in UTC.

Returns:

  • (Time)


11
# File 'lib/deeprails/models/defend_update_response.rb', line 11

required :modified_at, Time

#name ⇒ String?

The name of the workflow.

Returns:

  • (String, nil)


30
# File 'lib/deeprails/models/defend_update_response.rb', line 30

optional :name, String

#status ⇒ Symbol, Deeprails::Models::DefendUpdateResponse::Status

Status of the selected workflow. May be inactive or active. Inactive workflows will not accept events.



18
# File 'lib/deeprails/models/defend_update_response.rb', line 18

required :status, enum: -> { Deeprails::DefendUpdateResponse::Status }

#workflow_id ⇒ String

A unique workflow ID.

Returns:

  • (String)


24
# File 'lib/deeprails/models/defend_update_response.rb', line 24

required :workflow_id, String