Module: Deeprails::Models::DefendUpdateWorkflowParams::AutomaticHallucinationToleranceLevel

Extended by:
Internal::Type::Enum
Defined in:
lib/deeprails/models/defend_update_workflow_params.rb

Constant Summary collapse

LOW =
:low
MEDIUM =
:medium
HIGH =
:high

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(workflow_id:, automatic_hallucination_tolerance_levels: nil, context_awareness: nil, custom_hallucination_threshold_values: nil, description: nil, file_search: nil, improvement_action: nil, max_improvement_attempts: nil, name: nil, threshold_type: nil, web_search: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Deeprails::Models::DefendUpdateWorkflowParams for more details.

Parameters:

  • workflow_id (String)
  • automatic_hallucination_tolerance_levels (Hash{Symbol=>Symbol, Deeprails::Models::DefendUpdateWorkflowParams::AutomaticHallucinationToleranceLevel}) (defaults to: nil)

    New mapping of guardrail metrics to hallucination tolerance levels

  • context_awareness (Boolean) (defaults to: nil)

    Whether to enable context awareness for this workflow’s evaluations.

  • custom_hallucination_threshold_values (Hash{Symbol=>Float}) (defaults to: nil)

    New mapping of guardrail metrics to floating point threshold values to be used w

  • description (String) (defaults to: nil)

    New description for the workflow.

  • file_search (Array<String>) (defaults to: nil)

    An array of file IDs to search in the workflow’s evaluations. Files must be uplo

  • improvement_action (Symbol, Deeprails::Models::DefendUpdateWorkflowParams::ImprovementAction) (defaults to: nil)

    The new action used to improve outputs that fail one or more guardrail metrics f

  • max_improvement_attempts (Integer) (defaults to: nil)

    Max. number of improvement action attempts until a given event passes the guardr

  • name (String) (defaults to: nil)

    New name for the workflow.

  • threshold_type (Symbol, Deeprails::Models::DefendUpdateWorkflowParams::ThresholdType) (defaults to: nil)

    New type of thresholds to use for the workflow, either automatic or custom.

  • web_search (Boolean) (defaults to: nil)

    Whether to enable web search for this workflow’s evaluations.

  • request_options (Deeprails::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


120
121
122
123
124
125
126
127
128
129
# File 'lib/deeprails/models/defend_update_workflow_params.rb', line 120

module AutomaticHallucinationToleranceLevel
  extend Deeprails::Internal::Type::Enum

  LOW = :low
  MEDIUM = :medium
  HIGH = :high

  # @!method self.values
  #   @return [Array<Symbol>]
end