Module: Deeprails::Models::DefendUpdateWorkflowParams::ThresholdType
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/deeprails/models/defend_update_workflow_params.rb
Overview
New type of thresholds to use for the workflow, either automatic or custom.
Automatic thresholds are assigned internally after the user specifies a
qualitative tolerance for the metrics, whereas custom metrics allow the user to
set the threshold for each metric as a floating point number between 0.0 and
1.0.
Constant Summary collapse
- AUTOMATIC =
:automatic- CUSTOM =
:custom
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/deeprails/models/defend_update_workflow_params.rb', line 158
|