Class: Deeprails::Models::MonitorDetailResponse::Evaluation::ModelInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/deeprails/models/monitor_detail_response.rb

Overview

See Also:

Defined Under Namespace

Classes: Context

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Deeprails::Internal::Type::BaseModel

Instance Attribute Details

#context ⇒ Array<Deeprails::Models::MonitorDetailResponse::Evaluation::ModelInput::Context>?

Any structured information that directly relates to the model’s input and expected output—e.g., the recent turn-by-turn history between an AI tutor and a student, facts or state passed through an agentic workflow, or other domain-specific signals your system already knows and wants the model to condition on.



243
244
# File 'lib/deeprails/models/monitor_detail_response.rb', line 243

optional :context,
-> { Deeprails::Internal::Type::ArrayOf[Deeprails::MonitorDetailResponse::Evaluation::ModelInput::Context] }

#ground_truth ⇒ String?

The ground truth for evaluating Ground Truth Adherence guardrail.

Returns:

  • (String, nil)


250
# File 'lib/deeprails/models/monitor_detail_response.rb', line 250

optional :ground_truth, String

#system_prompt ⇒ String?

The system prompt used to generate the output.

Returns:

  • (String, nil)


256
# File 'lib/deeprails/models/monitor_detail_response.rb', line 256

optional :system_prompt, String

#user_prompt ⇒ String

The user prompt used to generate the output.

Returns:

  • (String)


233
# File 'lib/deeprails/models/monitor_detail_response.rb', line 233

required :user_prompt, String