Class: Deeprails::Models::MonitorEventDetailResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/deeprails/models/monitor_event_detail_response.rb

Overview

Defined Under Namespace

Modules: RunMode, Status Classes: Capability, File

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_id: nil, file_name: nil, file_size: nil) ⇒ Object

Parameters:

  • file_id (String) (defaults to: nil)

    The ID of the file.

  • file_name (String) (defaults to: nil)

    The name of the file.

  • file_size (Integer) (defaults to: nil)

    The size of the file in bytes.



# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 124


Instance Attribute Details

#capabilitiesArray<Deeprails::Models::MonitorEventDetailResponse::Capability>?

The extended AI capabilities associated with the monitor event. Can be web_search, file_search, and/or context_awareness.



12
13
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 12

optional :capabilities,
-> { Deeprails::Internal::Type::ArrayOf[Deeprails::MonitorEventDetailResponse::Capability] }

#eval_timeString?

The time spent on the evaluation in seconds.

Returns:

  • (String, nil)


19
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 19

optional :eval_time, String

#evaluation_resultHash{Symbol=>Object}?

The result of the evaluation of the monitor event.

Returns:

  • (Hash{Symbol=>Object}, nil)


25
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 25

optional :evaluation_result, Deeprails::Internal::Type::HashOf[Deeprails::Internal::Type::Unknown]

#event_idString?

A unique monitor event ID.

Returns:

  • (String, nil)


31
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 31

optional :event_id, String

#filesArray<Deeprails::Models::MonitorEventDetailResponse::File>?

The files associated with the monitor event.



37
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 37

optional :files, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::MonitorEventDetailResponse::File] }

#guardrail_metricsArray<String>?

The guardrail metrics evaluated by the monitor event.

Returns:

  • (Array<String>, nil)


43
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 43

optional :guardrail_metrics, Deeprails::Internal::Type::ArrayOf[String]

#model_inputHash{Symbol=>Object}?

The model input used to create the monitor event.

Returns:

  • (Hash{Symbol=>Object}, nil)


49
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 49

optional :model_input, Deeprails::Internal::Type::HashOf[Deeprails::Internal::Type::Unknown]

#model_outputString?

The output evaluated by the monitor event.

Returns:

  • (String, nil)


55
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 55

optional :model_output, String

#monitor_idString?

Monitor ID associated with this event.

Returns:

  • (String, nil)


61
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 61

optional :monitor_id, String

#nametagString?

A human-readable tag for the monitor event.

Returns:

  • (String, nil)


67
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 67

optional :nametag, String

#run_modeSymbol, ...

The run mode used to evaluate the monitor event.



73
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 73

optional :run_mode, enum: -> { Deeprails::MonitorEventDetailResponse::RunMode }

#statusSymbol, ...

Status of the monitor event's evaluation.



79
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 79

optional :status, enum: -> { Deeprails::MonitorEventDetailResponse::Status }

#timestampTime?

The time the monitor event was created in UTC.

Returns:

  • (Time, nil)


85
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 85

optional :timestamp, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 168