Class: Deeprails::Models::MonitorSubmitEventParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Deeprails::Models::MonitorSubmitEventParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/deeprails/models/monitor_submit_event_params.rb
Overview
Defined Under Namespace
Modules: RunMode Classes: ModelInput
Instance Attribute Summary collapse
-
#model_input ⇒ Deeprails::Models::MonitorSubmitEventParams::ModelInput
A dictionary of inputs sent to the LLM to generate output.
-
#model_output ⇒ String
Output generated by the LLM to be evaluated.
- #monitor_id ⇒ String
-
#nametag ⇒ String?
An optional, user-defined tag for the event.
-
#run_mode ⇒ Symbol, ...
Run mode for the monitor event.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(content: nil, role: nil) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content: nil, role: nil) ⇒ Object
|
|
# File 'lib/deeprails/models/monitor_submit_event_params.rb', line 122
|
Instance Attribute Details
#model_input ⇒ Deeprails::Models::MonitorSubmitEventParams::ModelInput
A dictionary of inputs sent to the LLM to generate output. The dictionary must
contain a user_prompt field. For ground_truth_adherence guardrail metric,
ground_truth should be provided.
21 |
# File 'lib/deeprails/models/monitor_submit_event_params.rb', line 21 required :model_input, -> { Deeprails::MonitorSubmitEventParams::ModelInput } |
#model_output ⇒ String
Output generated by the LLM to be evaluated.
27 |
# File 'lib/deeprails/models/monitor_submit_event_params.rb', line 27 required :model_output, String |
#monitor_id ⇒ String
13 |
# File 'lib/deeprails/models/monitor_submit_event_params.rb', line 13 required :monitor_id, String |
#nametag ⇒ String?
An optional, user-defined tag for the event.
33 |
# File 'lib/deeprails/models/monitor_submit_event_params.rb', line 33 optional :nametag, String |
#run_mode ⇒ Symbol, ...
Run mode for the monitor event. The run mode allows the user to optimize for
speed, accuracy, and cost by determining which models are used to evaluate the
event. Available run modes (fastest to most thorough): super_fast, fast,
precision, precision_codex, precision_max, and precision_max_codex.
Defaults to fast. Note: super_fast does not support Web Search or File
Search — if your monitor has these capabilities enabled, use a different run
mode or edit the monitor to disable them.
45 |
# File 'lib/deeprails/models/monitor_submit_event_params.rb', line 45 optional :run_mode, enum: -> { Deeprails::MonitorSubmitEventParams::RunMode } |