Class: Deeprails::Models::WorkflowEventDetailResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/deeprails/models/workflow_event_detail_response.rb

Overview

Defined Under Namespace

Modules: AutomaticHallucinationToleranceLevel, ImprovementAction, ImprovementToolStatus, Status, ThresholdType Classes: Capability, EvaluationHistory, File, KeyImprovement

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(capability: nil) ⇒ Object

Parameters:

  • capability (String) (defaults to: nil)


# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 311

Instance Attribute Details

#analysis_of_failuresArray<String>

Returns:

  • (Array<String>)


10
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 10

required :analysis_of_failures, Deeprails::Internal::Type::ArrayOf[String]

#automatic_hallucination_tolerance_levelsHash{Symbol=>Symbol, Deeprails::Models::WorkflowEventDetailResponse::AutomaticHallucinationToleranceLevel}?

Mapping of guardrail metric names to tolerance values. Values are strings (low, medium, high) representing automatic tolerance levels.



93
94
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 93

optional :automatic_hallucination_tolerance_levels,
-> { Deeprails::Internal::Type::HashOf[enum: Deeprails::WorkflowEventDetailResponse::AutomaticHallucinationToleranceLevel] }

#capabilitiesArray<Deeprails::Models::WorkflowEventDetailResponse::Capability>?

Extended AI capabilities available to the event, if any. Can be web_search, file_search, and/or context_awareness.



101
102
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 101

optional :capabilities,
-> { Deeprails::Internal::Type::ArrayOf[Deeprails::WorkflowEventDetailResponse::Capability] }

#custom_hallucination_threshold_valuesHash{Symbol=>Float}?

Mapping of guardrail metric names to threshold values. Values are floating point numbers (0.0-1.0) representing custom thresholds.

Returns:

  • (Hash{Symbol=>Float}, nil)


109
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 109

optional :custom_hallucination_threshold_values, Deeprails::Internal::Type::HashOf[Float]

#evaluation_historyArray<Deeprails::Models::WorkflowEventDetailResponse::EvaluationHistory>

History of evaluations for the event.



16
17
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 16

required :evaluation_history,
-> { Deeprails::Internal::Type::ArrayOf[Deeprails::WorkflowEventDetailResponse::EvaluationHistory] }

#evaluation_resultHash{Symbol=>Object}

Evaluation result consisting of average scores and rationales for each of the evaluated guardrail metrics.

Returns:

  • (Hash{Symbol=>Object})


24
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 24

required :evaluation_result, Deeprails::Internal::Type::HashOf[Deeprails::Internal::Type::Unknown]

#event_idString

A unique workflow event ID.

Returns:

  • (String)


30
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 30

required :event_id, String

#filesArray<Deeprails::Models::WorkflowEventDetailResponse::File>?

List of files available to the event, if any. Will only be present if file_search is enabled.



116
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 116

optional :files, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::WorkflowEventDetailResponse::File] }

#filteredBoolean

Whether the event was filtered and requires improvement.

Returns:

  • (Boolean)


36
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 36

required :filtered, Deeprails::Internal::Type::Boolean

#improved_model_outputString

Improved model output after improvement tool was applied and each metric passed evaluation.

Returns:

  • (String)


43
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 43

required :improved_model_output, String

#improvement_actionSymbol, Deeprails::Models::WorkflowEventDetailResponse::ImprovementAction

Type of improvement action used to improve the event.



49
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 49

required :improvement_action, enum: -> { Deeprails::WorkflowEventDetailResponse::ImprovementAction }

#improvement_tool_statusSymbol, ...

Status of the improvement tool used to improve the event. improvement_required indicates that the evaluation is complete and the improvement action is needed but is not taking place. improved and improvement_failed indicate when the improvement action concludes, successfully and unsuccessfully, respectively. no_improvement_required means that the first evaluation passed all its metrics!



60
61
62
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 60

required :improvement_tool_status,
enum: -> { Deeprails::WorkflowEventDetailResponse::ImprovementToolStatus },
nil?: true

#key_improvementsArray<Deeprails::Models::WorkflowEventDetailResponse::KeyImprovement>



67
68
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 67

required :key_improvements,
-> { Deeprails::Internal::Type::ArrayOf[Deeprails::WorkflowEventDetailResponse::KeyImprovement] }

#max_improvement_attemptsInteger?

The maximum number of improvement attempts to be applied to one event before it is considered failed.

Returns:

  • (Integer, nil)


123
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 123

optional :max_improvement_attempts, Integer

#statusSymbol, Deeprails::Models::WorkflowEventDetailResponse::Status

Status of the event.



74
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 74

required :status, enum: -> { Deeprails::WorkflowEventDetailResponse::Status }

#threshold_typeSymbol, Deeprails::Models::WorkflowEventDetailResponse::ThresholdType

Type of thresholds used to evaluate the event.



80
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 80

required :threshold_type, enum: -> { Deeprails::WorkflowEventDetailResponse::ThresholdType }

#workflow_idString

Workflow ID associated with the event.

Returns:

  • (String)


86
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 86

required :workflow_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 266