Class: Deeprails::Models::DefendResponse::Event
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Deeprails::Models::DefendResponse::Event
- Defined in:
- lib/deeprails/models/defend_response.rb
Defined Under Namespace
Modules: ImprovementToolStatus, Status Classes: Evaluation
Instance Attribute Summary collapse
-
#billing_request_id ⇒ String?
The ID of the billing request for the event.
-
#evaluations ⇒ Array<Deeprails::Models::DefendResponse::Event::Evaluation>?
An array of evaluations for this event.
-
#event_id ⇒ String?
A unique workflow event ID.
-
#improved_model_output ⇒ String?
Improved model output after improvement tool was applied.
-
#improvement_tool_status ⇒ Symbol, ...
Status of the improvement tool used to improve the event.
-
#status ⇒ Symbol, ...
Status of the event.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Deeprails::Internal::Type::BaseModel
Instance Attribute Details
#billing_request_id ⇒ String?
The ID of the billing request for the event.
156 |
# File 'lib/deeprails/models/defend_response.rb', line 156 optional :billing_request_id, String |
#evaluations ⇒ Array<Deeprails::Models::DefendResponse::Event::Evaluation>?
An array of evaluations for this event.
162 163 |
# File 'lib/deeprails/models/defend_response.rb', line 162 optional :evaluations, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::DefendResponse::Event::Evaluation] } |
#event_id ⇒ String?
A unique workflow event ID.
169 |
# File 'lib/deeprails/models/defend_response.rb', line 169 optional :event_id, String |
#improved_model_output ⇒ String?
Improved model output after improvement tool was applied.
175 |
# File 'lib/deeprails/models/defend_response.rb', line 175 optional :improved_model_output, String |
#improvement_tool_status ⇒ Symbol, ...
Status of the improvement tool used to improve the event. improvement_required indicates that the evaluation is complete and the improvement action is needed but is not taking place. improved and improvement_failed indicate when the improvement action concludes, successfully and unsuccessfully, respectively. no_improvement_required means that the first evaluation passed all its metrics!
186 |
# File 'lib/deeprails/models/defend_response.rb', line 186 optional :improvement_tool_status, enum: -> { Deeprails::DefendResponse::Event::ImprovementToolStatus } |
#status ⇒ Symbol, ...
Status of the event.
192 |
# File 'lib/deeprails/models/defend_response.rb', line 192 optional :status, enum: -> { Deeprails::DefendResponse::Event::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/deeprails/models/defend_response.rb', line 366
|