Class: Deeprails::Models::DefendSubmitAndStreamEventParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Deeprails::Models::DefendSubmitAndStreamEventParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/deeprails/models/defend_submit_and_stream_event_params.rb
Overview
Defined Under Namespace
Modules: RunMode
Instance Attribute Summary collapse
-
#model_input ⇒ Hash{Symbol=>Object}
The input provided to the model (e.g., prompt, messages).
-
#model_output ⇒ String
The output generated by the model to be evaluated.
-
#model_used ⇒ String
The model that generated the output (e.g., “gpt-4”, “claude-3”).
-
#nametag ⇒ String?
Optional tag to identify this event.
-
#run_mode ⇒ Symbol, Deeprails::Models::DefendSubmitAndStreamEventParams::RunMode
The evaluation run mode.
-
#stream ⇒ Boolean?
Enable SSE streaming for real-time token feedback.
- #workflow_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(workflow_id:, model_input:, model_output:, model_used:, run_mode:, stream: nil, nametag: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DefendSubmitAndStreamEventParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workflow_id:, model_input:, model_output:, model_used:, run_mode:, stream: nil, nametag: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Deeprails::Models::DefendSubmitAndStreamEventParams for more details.
|
|
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 55
|
Instance Attribute Details
#model_input ⇒ Hash{Symbol=>Object}
The input provided to the model (e.g., prompt, messages).
19 |
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 19 required :model_input, Deeprails::Internal::Type::HashOf[Deeprails::Internal::Type::Unknown] |
#model_output ⇒ String
The output generated by the model to be evaluated.
25 |
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 25 required :model_output, String |
#model_used ⇒ String
The model that generated the output (e.g., “gpt-4”, “claude-3”).
31 |
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 31 required :model_used, String |
#nametag ⇒ String?
Optional tag to identify this event.
53 |
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 53 optional :nametag, String |
#run_mode ⇒ Symbol, Deeprails::Models::DefendSubmitAndStreamEventParams::RunMode
The evaluation run mode. Streaming is supported on all run modes except precision_max and precision_max_codex. Note: super_fast does not support Web Search or File Search — if your workflow has these enabled, use a different run mode or disable the capability on the workflow.
40 |
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 40 required :run_mode, enum: -> { Deeprails::DefendSubmitAndStreamEventParams::RunMode } |
#stream ⇒ Boolean?
Enable SSE streaming for real-time token feedback. Supported on all run modes except precision_max and precision_max_codex.
47 |
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 47 optional :stream, Deeprails::Internal::Type::Boolean |
#workflow_id ⇒ String
13 |
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 13 required :workflow_id, String |