Module: Deeprails::Models::DefendSubmitAndStreamEventParams::RunMode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/deeprails/models/defend_submit_and_stream_event_params.rb
Overview
The evaluation run mode. Streaming is supported on all run modes except precision_max and precision_max_codex. Note: super_fast does not support Web Search or File Search — if your workflow has these enabled, use a different run mode or disable the capability on the workflow.
Constant Summary collapse
- SUPER_FAST =
:super_fast- FAST =
:fast- PRECISION =
:precision- PRECISION_CODEX =
:precision_codex
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/deeprails/models/defend_submit_and_stream_event_params.rb', line 87
|