Module: Deeprails::Models::DefendSubmitEventParams::RunMode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/deeprails/models/defend_submit_event_params.rb
Overview
Run mode for the workflow event. The run mode allows the user to optimize for speed, accuracy, and cost by determining which models are used to evaluate the event. Available run modes (fastest to most thorough): super_fast, fast, precision, precision_codex, precision_max, and precision_max_codex. Defaults to fast. Note: super_fast does not support Web Search or File Search — if your workflow has these capabilities enabled, use a different run mode or edit the workflow to disable them.
Constant Summary collapse
- SUPER_FAST =
:super_fast- FAST =
:fast- PRECISION =
:precision- PRECISION_CODEX =
:precision_codex- PRECISION_MAX =
:precision_max- PRECISION_MAX_CODEX =
:precision_max_codex
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/deeprails/models/defend_submit_event_params.rb', line 154
|