Class: Deeprails::Models::MonitorEventDetailResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Deeprails::Models::MonitorEventDetailResponse
- Defined in:
- lib/deeprails/models/monitor_event_detail_response.rb
Overview
Defined Under Namespace
Modules: RunMode, Status Classes: Capability, File
Instance Attribute Summary collapse
-
#capabilities ⇒ Array<Deeprails::Models::MonitorEventDetailResponse::Capability>?
The extended AI capabilities associated with the monitor event.
-
#eval_time ⇒ String?
The time spent on the evaluation in seconds.
-
#evaluation_result ⇒ Hash{Symbol=>Object}?
The result of the evaluation of the monitor event.
-
#event_id ⇒ String?
A unique monitor event ID.
-
#files ⇒ Array<Deeprails::Models::MonitorEventDetailResponse::File>?
The files associated with the monitor event.
-
#guardrail_metrics ⇒ Array<String>?
The guardrail metrics evaluated by the monitor event.
-
#model_input ⇒ Hash{Symbol=>Object}?
The model input used to create the monitor event.
-
#model_output ⇒ String?
The output evaluated by the monitor event.
-
#monitor_id ⇒ String?
Monitor ID associated with this event.
-
#nametag ⇒ String?
A human-readable tag for the monitor event.
-
#run_mode ⇒ Symbol, ...
The run mode used to evaluate the monitor event.
-
#status ⇒ Symbol, ...
Status of the monitor event's evaluation.
-
#timestamp ⇒ Time?
The time the monitor event was created in UTC.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_id: nil, file_name: nil, file_size: nil) ⇒ Object
|
|
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 124
|
Instance Attribute Details
#capabilities ⇒ Array<Deeprails::Models::MonitorEventDetailResponse::Capability>?
The extended AI capabilities associated with the monitor event. Can be
web_search, file_search, and/or context_awareness.
12 13 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 12 optional :capabilities, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::MonitorEventDetailResponse::Capability] } |
#eval_time ⇒ String?
The time spent on the evaluation in seconds.
19 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 19 optional :eval_time, String |
#evaluation_result ⇒ Hash{Symbol=>Object}?
The result of the evaluation of the monitor event.
25 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 25 optional :evaluation_result, Deeprails::Internal::Type::HashOf[Deeprails::Internal::Type::Unknown] |
#event_id ⇒ String?
A unique monitor event ID.
31 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 31 optional :event_id, String |
#files ⇒ Array<Deeprails::Models::MonitorEventDetailResponse::File>?
The files associated with the monitor event.
37 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 37 optional :files, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::MonitorEventDetailResponse::File] } |
#guardrail_metrics ⇒ Array<String>?
The guardrail metrics evaluated by the monitor event.
43 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 43 optional :guardrail_metrics, Deeprails::Internal::Type::ArrayOf[String] |
#model_input ⇒ Hash{Symbol=>Object}?
The model input used to create the monitor event.
49 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 49 optional :model_input, Deeprails::Internal::Type::HashOf[Deeprails::Internal::Type::Unknown] |
#model_output ⇒ String?
The output evaluated by the monitor event.
55 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 55 optional :model_output, String |
#monitor_id ⇒ String?
Monitor ID associated with this event.
61 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 61 optional :monitor_id, String |
#nametag ⇒ String?
A human-readable tag for the monitor event.
67 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 67 optional :nametag, String |
#run_mode ⇒ Symbol, ...
The run mode used to evaluate the monitor event.
73 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 73 optional :run_mode, enum: -> { Deeprails::MonitorEventDetailResponse::RunMode } |
#status ⇒ Symbol, ...
Status of the monitor event's evaluation.
79 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 79 optional :status, enum: -> { Deeprails::MonitorEventDetailResponse::Status } |
#timestamp ⇒ Time?
The time the monitor event was created in UTC.
85 |
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 85 optional :timestamp, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/deeprails/models/monitor_event_detail_response.rb', line 168
|