Class: Deeprails::Models::MonitorUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Deeprails::Models::MonitorUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/deeprails/models/monitor_update_params.rb
Overview
Defined Under Namespace
Modules: GuardrailMetric, Status
Instance Attribute Summary collapse
-
#description ⇒ String?
New description of the monitor.
-
#file_search ⇒ Array<String>?
An array of file IDs to search in the monitor’s evaluations.
-
#guardrail_metrics ⇒ Array<Symbol, Deeprails::Models::MonitorUpdateParams::GuardrailMetric>?
An array of the new guardrail metrics that model input and output pairs will be evaluated on.
- #monitor_id ⇒ String
-
#name ⇒ String?
New name of the monitor.
-
#status ⇒ Symbol, ...
Status of the monitor.
-
#web_search ⇒ Boolean?
Whether to enable web search for this monitor’s evaluations.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Deeprails::Internal::Type::BaseModel
Instance Attribute Details
#description ⇒ String?
New description of the monitor.
19 |
# File 'lib/deeprails/models/monitor_update_params.rb', line 19 optional :description, String |
#file_search ⇒ Array<String>?
An array of file IDs to search in the monitor’s evaluations. Files must be uploaded via the DeepRails API first.
26 |
# File 'lib/deeprails/models/monitor_update_params.rb', line 26 optional :file_search, Deeprails::Internal::Type::ArrayOf[String] |
#guardrail_metrics ⇒ Array<Symbol, Deeprails::Models::MonitorUpdateParams::GuardrailMetric>?
An array of the new guardrail metrics that model input and output pairs will be evaluated on.
33 34 |
# File 'lib/deeprails/models/monitor_update_params.rb', line 33 optional :guardrail_metrics, -> { Deeprails::Internal::Type::ArrayOf[enum: Deeprails::MonitorUpdateParams::GuardrailMetric] } |
#monitor_id ⇒ String
13 |
# File 'lib/deeprails/models/monitor_update_params.rb', line 13 required :monitor_id, String |
#name ⇒ String?
New name of the monitor.
40 |
# File 'lib/deeprails/models/monitor_update_params.rb', line 40 optional :name, String |
#status ⇒ Symbol, ...
Status of the monitor. Can be active or inactive. Inactive monitors no longer record and evaluate events.
47 |
# File 'lib/deeprails/models/monitor_update_params.rb', line 47 optional :status, enum: -> { Deeprails::MonitorUpdateParams::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/deeprails/models/monitor_update_params.rb', line 85
|