Class: Deeprails::Models::WorkflowEventDetailResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Deeprails::Models::WorkflowEventDetailResponse
- Defined in:
- lib/deeprails/models/workflow_event_detail_response.rb
Overview
Defined Under Namespace
Modules: AutomaticHallucinationToleranceLevel, ImprovementAction, ImprovementToolStatus, Status, ThresholdType Classes: Capability, EvaluationHistory, File, KeyImprovement
Instance Attribute Summary collapse
- #analysis_of_failures ⇒ Array<String>
-
#automatic_hallucination_tolerance_levels ⇒ Hash{Symbol=>Symbol, Deeprails::Models::WorkflowEventDetailResponse::AutomaticHallucinationToleranceLevel}?
Mapping of guardrail metric names to tolerance values.
-
#capabilities ⇒ Array<Deeprails::Models::WorkflowEventDetailResponse::Capability>?
Extended AI capabilities available to the event, if any.
-
#custom_hallucination_threshold_values ⇒ Hash{Symbol=>Float}?
Mapping of guardrail metric names to threshold values.
-
#evaluation_history ⇒ Array<Deeprails::Models::WorkflowEventDetailResponse::EvaluationHistory>
History of evaluations for the event.
-
#evaluation_result ⇒ Hash{Symbol=>Object}
Evaluation result consisting of average scores and rationales for each of the evaluated guardrail metrics.
-
#event_id ⇒ String
A unique workflow event ID.
-
#files ⇒ Array<Deeprails::Models::WorkflowEventDetailResponse::File>?
List of files available to the event, if any.
-
#filtered ⇒ Boolean
Whether the event was filtered and requires improvement.
-
#improved_model_output ⇒ String
Improved model output after improvement tool was applied and each metric passed evaluation.
-
#improvement_action ⇒ Symbol, Deeprails::Models::WorkflowEventDetailResponse::ImprovementAction
Type of improvement action used to improve the event.
-
#improvement_tool_status ⇒ Symbol, ...
Status of the improvement tool used to improve the event.
- #key_improvements ⇒ Array<Deeprails::Models::WorkflowEventDetailResponse::KeyImprovement>
-
#max_improvement_attempts ⇒ Integer?
The maximum number of improvement attempts to be applied to one event before it is considered failed.
-
#status ⇒ Symbol, Deeprails::Models::WorkflowEventDetailResponse::Status
Status of the event.
-
#threshold_type ⇒ Symbol, Deeprails::Models::WorkflowEventDetailResponse::ThresholdType
Type of thresholds used to evaluate the event.
-
#workflow_id ⇒ String
Workflow ID associated with the event.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(capability: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(capability: nil) ⇒ Object
|
|
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 311
|
Instance Attribute Details
#analysis_of_failures ⇒ Array<String>
10 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 10 required :analysis_of_failures, Deeprails::Internal::Type::ArrayOf[String] |
#automatic_hallucination_tolerance_levels ⇒ Hash{Symbol=>Symbol, Deeprails::Models::WorkflowEventDetailResponse::AutomaticHallucinationToleranceLevel}?
Mapping of guardrail metric names to tolerance values. Values are strings (low, medium, high) representing automatic tolerance levels.
93 94 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 93 optional :automatic_hallucination_tolerance_levels, -> { Deeprails::Internal::Type::HashOf[enum: Deeprails::WorkflowEventDetailResponse::AutomaticHallucinationToleranceLevel] } |
#capabilities ⇒ Array<Deeprails::Models::WorkflowEventDetailResponse::Capability>?
Extended AI capabilities available to the event, if any. Can be web_search, file_search, and/or context_awareness.
101 102 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 101 optional :capabilities, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::WorkflowEventDetailResponse::Capability] } |
#custom_hallucination_threshold_values ⇒ Hash{Symbol=>Float}?
Mapping of guardrail metric names to threshold values. Values are floating point numbers (0.0-1.0) representing custom thresholds.
109 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 109 optional :custom_hallucination_threshold_values, Deeprails::Internal::Type::HashOf[Float] |
#evaluation_history ⇒ Array<Deeprails::Models::WorkflowEventDetailResponse::EvaluationHistory>
History of evaluations for the event.
16 17 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 16 required :evaluation_history, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::WorkflowEventDetailResponse::EvaluationHistory] } |
#evaluation_result ⇒ Hash{Symbol=>Object}
Evaluation result consisting of average scores and rationales for each of the evaluated guardrail metrics.
24 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 24 required :evaluation_result, Deeprails::Internal::Type::HashOf[Deeprails::Internal::Type::Unknown] |
#event_id ⇒ String
A unique workflow event ID.
30 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 30 required :event_id, String |
#files ⇒ Array<Deeprails::Models::WorkflowEventDetailResponse::File>?
List of files available to the event, if any. Will only be present if file_search is enabled.
116 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 116 optional :files, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::WorkflowEventDetailResponse::File] } |
#filtered ⇒ Boolean
Whether the event was filtered and requires improvement.
36 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 36 required :filtered, Deeprails::Internal::Type::Boolean |
#improved_model_output ⇒ String
Improved model output after improvement tool was applied and each metric passed evaluation.
43 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 43 required :improved_model_output, String |
#improvement_action ⇒ Symbol, Deeprails::Models::WorkflowEventDetailResponse::ImprovementAction
Type of improvement action used to improve the event.
49 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 49 required :improvement_action, enum: -> { Deeprails::WorkflowEventDetailResponse::ImprovementAction } |
#improvement_tool_status ⇒ Symbol, ...
Status of the improvement tool used to improve the event. improvement_required indicates that the evaluation is complete and the improvement action is needed but is not taking place. improved and improvement_failed indicate when the improvement action concludes, successfully and unsuccessfully, respectively. no_improvement_required means that the first evaluation passed all its metrics!
60 61 62 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 60 required :improvement_tool_status, enum: -> { Deeprails::WorkflowEventDetailResponse::ImprovementToolStatus }, nil?: true |
#key_improvements ⇒ Array<Deeprails::Models::WorkflowEventDetailResponse::KeyImprovement>
67 68 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 67 required :key_improvements, -> { Deeprails::Internal::Type::ArrayOf[Deeprails::WorkflowEventDetailResponse::KeyImprovement] } |
#max_improvement_attempts ⇒ Integer?
The maximum number of improvement attempts to be applied to one event before it is considered failed.
123 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 123 optional :max_improvement_attempts, Integer |
#status ⇒ Symbol, Deeprails::Models::WorkflowEventDetailResponse::Status
Status of the event.
74 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 74 required :status, enum: -> { Deeprails::WorkflowEventDetailResponse::Status } |
#threshold_type ⇒ Symbol, Deeprails::Models::WorkflowEventDetailResponse::ThresholdType
Type of thresholds used to evaluate the event.
80 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 80 required :threshold_type, enum: -> { Deeprails::WorkflowEventDetailResponse::ThresholdType } |
#workflow_id ⇒ String
Workflow ID associated with the event.
86 |
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 86 required :workflow_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/deeprails/models/workflow_event_detail_response.rb', line 266
|